]> the.earth.li Git - onak.git/blobdiff - keydb.h
Move dumpdb over to using iterate_keys.
[onak.git] / keydb.h
diff --git a/keydb.h b/keydb.h
index e9bcb6751f275fc1d8607527419ddb9b882e7ae2..44062234d28714cbe672a06f1193340fd366f398 100644 (file)
--- a/keydb.h
+++ b/keydb.h
@@ -3,13 +3,12 @@
  *
  * Jonathan McDowell <noodles@earth.li>
  *
- * Copyright 2002 Project Purple
+ * Copyright 2002-2004 Project Purple
  */
 
 #ifndef __KEYDB_H__
 #define __KEYDB_H__
 
-// #include <stdint.h>
 #include <inttypes.h>
 
 #include "keystructs.h"
 
 /**
  *     initdb - Initialize the key database.
+ *     @readonly: If we'll only be reading the DB, not writing to it.
  *
  *     This function should be called before any of the other functions in
  *     this file are called in order to allow the DB to be initialized ready
  *     for access.
  */
-void initdb(void);
+void initdb(bool readonly);
 
 /**
  *     cleanupdb - De-initialize the key database.
@@ -97,6 +97,22 @@ int delete_key(uint64_t keyid, bool intrans);
  */
 int fetch_key_text(const char *search, struct openpgp_publickey **publickey);
 
+/**
+ *     update_keys - Takes a list of public keys and updates them in the DB.
+ *     @keys: The keys to update in the DB.
+ *     @sendsync: If we should send a keysync mail.
+ *
+ *     Takes a list of keys and adds them to the database, merging them with
+ *     the key in the database if it's already present there. The key list is
+ *     update to contain the minimum set of updates required to get from what
+ *     we had before to what we have now (ie the set of data that was added to
+ *     the DB). Returns the number of entirely new keys added.
+ *
+ *     If sendsync is true then we send out a keysync mail to our sync peers
+ *     with the update.
+ */
+int update_keys(struct openpgp_publickey **keys, bool sendsync);
+
 /**
  *     keyid2uid - Takes a keyid and returns the primary UID for it.
  *     @keyid: The keyid to lookup.
@@ -109,19 +125,44 @@ char *keyid2uid(uint64_t keyid);
 /**
  *     getkeysigs - Gets a linked list of the signatures on a key.
  *     @keyid: The keyid to get the sigs for.
+ *     @revoked: Is the key revoked?
  *
  *     This function gets the list of signatures on a key. Used for key 
*     indexing and doing stats bits.
  */
-struct ll *getkeysigs(uint64_t keyid);
+struct ll *getkeysigs(uint64_t keyid, bool *revoked);
+
+/**
+ *     cached_getkeysigs - Gets the signatures on a key.
+ *     @keyid: The key we want the signatures for.
+ *     
+ *     This function gets the signatures on a key. It's the same as the
+ *     getkeysigs function above except we use the hash module to cache the
+ */
+struct ll *cached_getkeysigs(uint64_t keyid);
 
 /**
  *     getfullkeyid - Maps a 32bit key id to a 64bit one.
  *     @keyid: The 32bit keyid.
  *
  *     This function maps a 32bit key id to the full 64bit one. It returns the
- *     full keyid.
+ *     full keyid. If the key isn't found a keyid of 0 is returned.
  */
 uint64_t getfullkeyid(uint64_t keyid);
 
+/**
+ *     iterate_keys - call a function once for each key in the db.
+ *     @iterfunc: The function to call.
+ *     @ctx: A context pointer
+ *
+ *     Calls iterfunc once for each key in the database. ctx is passed
+ *     unaltered to iterfunc. This function is intended to aid database dumps
+ *     and statistic calculations.
+ *
+ *     Returns the number of keys we iterated over.
+ */
+int iterate_keys(void (*iterfunc)(void *ctx, struct openpgp_publickey *key),
+               void *ctx);
+
 #endif /* __KEYDB_H__ */
@@ -109,19 +125,44 @@ char *keyid2uid(uint64_t keyid);
  *
  *     This function gets the list of signatures on a key. Used for key 
- *     indexing and doing stats bits.
+ *     indexing and doing stats bits. If revoked is non-NULL then if the key
+ *     is revoked it's set to true.
  */